zms._blobfields.MyFile

Package zms :: Module _blobfields :: Class MyFile |
[frames] | no frames]

# Class MyFile

                                                                                                                                                                                                                               object --+
                                                                                                                                                                                                                                        |
                                                                                                                                                                                                                                   MyBlob --+
                                                                                                                                                                                                                                            |
                                                                                                                                                                                                               Persistence.Persistent --+   |
                                                                                                                                                                                                                                        |   |
                                                                                                                                                                                                                 Acquisition.Implicit --+   |
                                                                                                                                                                                                                                        |   |
                ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+   |   |
                                                                                                                                                                                                                                    |   |   |
                                                                                                                                                                                                            OFS.ZDOM.Node --+       |   |   |
                                                                                                                                                                                                                            |       |   |   |
                                                                                                                                                                                                             OFS.ZDOM.Element --+   |   |   |
                                                                                                                                                                                                                                |   |   |   |
                                                                                                                                                                                                   OFS.ZDOM.ElementWithAttributes --+   |   |
                                                                                                                                                                                                                                    |   |   |
                                                                                                                                                                                                  OFS.PropertyManager.PropertyManager --+   |
                                                                                                                                                                                                                                        |   |
            ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+       |   |
                                                                                                                                                                                                                                |       |   |
                                                                                                                                                                                  AccessControl.PermissionMapping.RoleManager --+       |   |
                                                                                                                                                                                                                                |       |   |
                                                                                                                                                                                            AccessControl.rolemanager.RoleManager --+   |   |
                                                                                                                                                                                                                                    |   |   |
                                                                                                                                                                                                                 OFS.role.RoleManager --+   |
                                                                                                                                                                                                                                        |   |
            ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+       |   |
                                                                                                                                                                                                                                |       |   |
        ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+   |       |   |
                                                                                                                                                                                                                            |   |       |   |
                                                                                                                                                                                       webdav.EtagSupport.EtagSupport --+   |   |       |   |
                                                                                                                                                                                                                        |   |   |       |   |
                                                                                                                                                                                             webdav.Lockable.LockableItem --+   |       |   |
                                                                                                                                                                                                                            |   |       |   |
                                                                                                                                                                                                     webdav.Resource.Resource --+       |   |
                                                                                                                                                                                                                                |       |   |
        ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+   |       |   |
                                                                                                                                                                                                                            |   |       |   |
                                                                                                                                                                                                   OFS.CopySupport.CopySource --+       |   |
                                                                                                                                                                                                                                |       |   |
        ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+   |       |   |
                                                                                                                                                                                                                            |   |       |   |
                                                                                                                                                                                                          App.Management.Tabs --+       |   |
                                                                                                                                                                                                                                |       |   |
                                                                                                                                                                                                  OFS.Traversable.Traversable --+       |   |
                                                                                                                                                                                                                                |       |   |
                                                                                                                                                                                                            OFS.ZDOM.Node --+   |       |   |
                                                                                                                                                                                                                            |   |       |   |
                                                                                                                                                                                                             OFS.ZDOM.Element --+       |   |
                                                                                                                                                                                                                                |       |   |
    ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+       |       |   |
                                                                                                                                                                                                                        |       |       |   |
                                                                                                                                                                                                AccessControl.owner.Owned --+   |       |   |
                                                                                                                                                                                                                            |   |       |   |
                                                                                                                                                                                                              OFS.owner.Owned --+       |   |
                                                                                                                                                                                                                                |       |   |
        ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+   |       |   |
                                                                                                                                                                                                                            |   |       |   |
                                                                                                                                                                                                         App.Undo.UndoSupport --+       |   |
                                                                                                                                                                                                                                |       |   |
                                                                                                                                                                                                              OFS.SimpleItem.Item --+   |   |
                                                                                                                                                                                                                                    |   |   |
                                                                                                                                                                                                        OFS.SimpleItem.Item_w__name__ --+   |
                                                                                                                                                                                                                                        |   |
                                                                                                                                                                                                                  OFS.Cache.Cacheable --+   |
                                                                                                                                                                                                                                        |   |
                                                                                                                                                                                                                           OFS.Image.File --+
                                                                                                                                                                                                                                            |
                                                                                                                                                                                                                                           MyFile

Version: 0.1

Instance Methods
`str` |
toXml(self, sender=None, base_path='', data2hex=True) Serialize this file to xml-string. |
Inherited from `MyBlob`: `__bobo_traverse__`, `__call__`, `__str__`, `equals`, `getContentType`, `getData`, `getDataSizeStr`, `getFilename`, `getHref`, `getMediadbfile`, `getMimeTypeIconSrc`, `getObjAttrs`, `get_real_size`, `on_setobjattr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `OFS.Image.File`: `PUT`, `PrincipiaSearchSource`, `__len__`, `getSize`, `get_size`, `id`, `manage_FTPget`, `manage_edit`, `manage_upload`, `update_data`, `view_image_or_file` Inherited from `OFS.PropertyManager.PropertyManager`: `getProperty`, `getPropertyType`, `hasProperty`, `manage_addProperty`, `manage_changeProperties`, `manage_changePropertyTypes`, `manage_delProperties`, `manage_editProperties`, `propdict`, `propertyDescription`, `propertyIds`, `propertyItems`, `propertyLabel`, `propertyMap`, `propertyValues`, `valid_property_id` Inherited from `OFS.ZDOM.ElementWithAttributes`: `getAttribute`, `getAttributeNode`, `getAttributes` Inherited from `OFS.role.RoleManager`: `manage_access`, `manage_acquiredPermissions`, `manage_addLocalRoles`, `manage_changePermissions`, `manage_defined_roles`, `manage_delLocalRoles`, `manage_editRoles`, `manage_permission`, `manage_role`, `manage_setLocalRoles` Inherited from `AccessControl.rolemanager.RoleManager`: `ac_inherited_permissions`, `access_debug_info`, `acquiredRolesAreUsedBy`, `get_local_roles`, `get_local_roles_for_userid`, `get_valid_userids`, `has_local_roles`, `manage_getUserRolesAndPermissions`, `permission_settings`, `permissionsOfRole`, `possible_permissions`, `rolesOfPermission`, `userdefined_roles`, `users_with_local_role`, `valid_roles`, `validate_roles` Inherited from `AccessControl.PermissionMapping.RoleManager`: `manage_getPermissionMapping`, `manage_setPermissionMapping` Inherited from `OFS.SimpleItem.Item_w__name__`: `getId`, `getPhysicalPath`, `title_and_id`, `title_or_id` Inherited from `OFS.SimpleItem.Item`: `manage_FTPlist`, `manage_FTPstat`, `manage_afterAdd`, `manage_afterClone`, `manage_beforeDelete`, `manage_editedDialog`, `objectIds`, `objectItems`, `objectValues`, `raise_standardErrorMessage`, `this`, `tpURL`, `tpValues` Inherited from `webdav.Resource.Resource`: `COPY`, `DELETE`, `HEAD`, `LOCK`, `MKCOL`, `MOVE`, `OPTIONS`, `PROPFIND`, `PROPPATCH`, `TRACE`, `UNLOCK`, `dav__init`, `dav__simpleifhandler`, `dav__validate`, `listDAVObjects`, `manage_DAVget` Inherited from `webdav.Lockable.LockableItem`: `wl_clearLocks`, `wl_delLock`, `wl_getLock`, `wl_hasLock`, `wl_isLocked`, `wl_lockItems`, `wl_lockTokens`, `wl_lockValues`, `wl_lockmapping`, `wl_setLock` Inherited from `webdav.EtagSupport.EtagSupport`: `http__etag`, `http__parseMatchList`, `http__processMatchHeaders`, `http__refreshEtag` Inherited from `OFS.CopySupport.CopySource`: `cb_isCopyable`, `cb_isMoveable`, `cb_userHasCopyOrMovePermission` Inherited from `App.Management.Tabs`: `filtered_manage_options`, `manage_workspace`, `tabs_path_default`, `tabs_path_info` Inherited from `OFS.Traversable.Traversable`: `absolute_url`, `absolute_url_path`, `restrictedTraverse`, `unrestrictedTraverse`, `virtual_url_path` Inherited from `OFS.ZDOM.Element`: `getChildNodes`, `getElementsByTagName`, `getFirstChild`, `getLastChild`, `getNextSibling`, `getNodeName`, `getNodeType`, `getParentNode`, `getPreviousSibling`, `getTagName` Inherited from `OFS.ZDOM.Node`: `getNodeValue`, `getOwnerDocument`, `hasChildNodes` Inherited from `OFS.owner.Owned`: `manage_changeOwnershipType`, `manage_takeOwnership` Inherited from `AccessControl.owner.Owned`: `changeOwnership`, `getOwner`, `getOwnerTuple`, `getWrappedOwner`, `manage_fixupOwnershipAfterAdd`, `owner_info`, `userCanTakeOwnership` Inherited from `App.Undo.UndoSupport`: `manage_undo_transactions`, `undoable_transactions` Inherited from `OFS.Cache.Cacheable`: `ZCacheable_configHTML`, `ZCacheable_enabled`, `ZCacheable_get`, `ZCacheable_getCache`, `ZCacheable_getManager`, `ZCacheable_getManagerId`, `ZCacheable_getManagerIds`, `ZCacheable_getManagerURL`, `ZCacheable_getModTime`, `ZCacheable_getObAndView`, `ZCacheable_invalidate`, `ZCacheable_isCachingEnabled`, `ZCacheable_set`, `ZCacheable_setEnabled`, `ZCacheable_setManagerId`

Class Variables
| __doc__ = `"""ZMS product module."""`
| __obj_attrs__ = `['content_type', 'size', 'data', 'filename', '`...``
| __xml_attrs__ = `['content_type']`
| __class_name__ = `'{{MyFile}}'`
Inherited from `MyBlob`: `__call____roles__`, `getContentType__roles__`, `getDataSizeStr__roles__`, `getData__roles__`, `getFilename__roles__`, `getHref__roles__`, `getMediadbfile__roles__`, `getMimeTypeIconSrc__roles__`, `getObjAttrs__roles__`, `get_real_size__roles__`, `get_size__roles__`, `index_html` Inherited from `OFS.Image.File`: `manage`, `manage_editForm`, `manage_main`, `manage_options`, `manage_uploadForm`, `meta_type`, `precondition`, `security`, `size` Inherited from `OFS.PropertyManager.PropertyManager`: `__propsets__`, `manage_propertiesForm`, `manage_propertyTypeForm`, `propertysheets`, `title` Inherited from `OFS.role.RoleManager`: `aclAChecked`, `aclEChecked`, `aclPChecked`, `manage_acquiredForm`, `manage_editLocalRoles`, `manage_listLocalRoles`, `manage_permissionForm`, `manage_reportUserPermissions`, `manage_roleForm`, `selectedRoles`, `smallRolesWidget`, `validRoles` Inherited from `AccessControl.rolemanager.RoleManager`: `__ac_local_roles__`, `__ac_roles__`, `permissionMappingPossibleValues` Inherited from `OFS.SimpleItem.Item`: `REQUEST`, `__allow_access_to_unprotected_subobjects__`, `__name__`, `icon`, `isPrincipiaFolderish`, `isTopLevelPrincipiaApplicationObject` Inherited from `webdav.Resource.Resource`: `__dav_resource__`, `__http_methods__` Inherited from `App.Management.Tabs`: `manage_tabs`, `manage_workspace__roles__` Inherited from `OFS.Traversable.Traversable`: `getPhysicalRoot` Inherited from `OFS.owner.Owned`: `manage_owner` Inherited from `App.Undo.UndoSupport`: `manage_UndoForm` Inherited from `OFS.Cache.Cacheable`: `ZCacheable_manage`

Properties
Inherited from `object`: `__class__`

Method Details

### toXml(self, sender=None, base_path='', data2hex=True) |
Serialize this file to xml-string. Parameters: `sender` (`zmsobject.ZMSObject=None`) - the sender-node `base_path` (`str=''`) - the base-path `data2hex` (`Bool=True`) - convert data inline to hex, otherwise saved to file in base-path Returns: `str` the xml-string

Class Variable Details

  ### __obj_attrs__ Value:
      ['content_type', 'size', 'data', 'filename', 'mediadbfile', 'aq_parent
      ']